searchData={"items":[{"type":"module","title":"Passbook","doc":"Documentation for `Passbook`.","ref":"Passbook.html"},{"type":"function","title":"Passbook.generate/7","doc":"Generates a signed .pkpass file.\n\nOptions:\n- `target_path`: Where to generate the .pkpass file. Defaults to tmp folder.\n- `pass_name`: The name of the .pkpass file. Defaults to a random 8 char string.\n- `delete_raw_pass` - If the raw pass files should be deleted, leaving only the .pkpass file. Defaults to `true`.","ref":"Passbook.html#generate/7"},{"type":"function","title":"Examples - Passbook.generate/7","doc":"iex> Passbook.generate(%Passbook.Pass{\n      background_color: \"rgb(23, 187, 82)\",\n      foreground_color: \"rgb(100, 10, 110)\",\n      barcode: %Passbook.LowerLevel.Barcode{\n        format: :qr,\n        alt_text: \"1234\",\n        message: \"qr-code-content\"\n      },\n      description: \"This is a pass description\",\n      organization_name: \"My Organization\",\n      pass_type_identifier: \"123\",\n      serial_number: \"serial-number-123\",\n      team_identifier: \"team-identifier\",\n      generic: %Passbook.PassStructure{\n        transit_type: :train,\n        primary_fields: [\n          %Passbook.LowerLevel.Field{\n            key: \"my-key\",\n            value: \"my-value\"\n          }\n        ]\n      }}, [\"icon.png\": \"path/to/file.png\", \"icon@2x.png\": \"path/to/file.png\"], \"path/to/wwdr.pem\", \"path/to/certificate.pem\", \"path/to/key.pem\", \"password\", target_path: System.tmp_dir!(), pass_name: \"mypass\")\n    {:ok, \"path/to/generated/mypass.pkpass\"}","ref":"Passbook.html#generate/7-examples"},{"type":"module","title":"Passbook.LowerLevel.Barcode","doc":"Information about a location beacon.\n\nAvailable in iOS 7.0.","ref":"Passbook.LowerLevel.Barcode.html"},{"type":"type","title":"Passbook.LowerLevel.Barcode.barcode_format/0","doc":"","ref":"Passbook.LowerLevel.Barcode.html#t:barcode_format/0"},{"type":"type","title":"Passbook.LowerLevel.Barcode.t/0","doc":"","ref":"Passbook.LowerLevel.Barcode.html#t:t/0"},{"type":"module","title":"Passbook.LowerLevel.Field","doc":"Keys, used at the lowest level of the pass.json file, that define an individual field.","ref":"Passbook.LowerLevel.Field.html"},{"type":"type","title":"Passbook.LowerLevel.Field.data_detector_types/0","doc":"","ref":"Passbook.LowerLevel.Field.html#t:data_detector_types/0"},{"type":"type","title":"Passbook.LowerLevel.Field.date_time_styles/0","doc":"","ref":"Passbook.LowerLevel.Field.html#t:date_time_styles/0"},{"type":"type","title":"Passbook.LowerLevel.Field.t/0","doc":"","ref":"Passbook.LowerLevel.Field.html#t:t/0"},{"type":"type","title":"Passbook.LowerLevel.Field.text_alignment/0","doc":"","ref":"Passbook.LowerLevel.Field.html#t:text_alignment/0"},{"type":"module","title":"Passbook.LowerLevel.Location","doc":"Information about a location.","ref":"Passbook.LowerLevel.Location.html"},{"type":"type","title":"Passbook.LowerLevel.Location.t/0","doc":"","ref":"Passbook.LowerLevel.Location.html#t:t/0"},{"type":"module","title":"Passbook.Pass","doc":"The top level of the pass.json file is a dictionary.\n\nMore info at: https://developer.apple.com/library/archive/documentation/UserExperience/Reference/PassKit_Bundle/Chapters/TopLevel.html#//apple_ref/doc/uid/TP40012026-CH2-SW1","ref":"Passbook.Pass.html"},{"type":"function","title":"Passbook.Pass.generate_json/1","doc":"","ref":"Passbook.Pass.html#generate_json/1"},{"type":"type","title":"Passbook.Pass.t/0","doc":"","ref":"Passbook.Pass.html#t:t/0"},{"type":"module","title":"Passbook.PassStructure","doc":"Keys that define the structure of the pass.\n\nThese keys are used for all pass styles and partition the fields into the various parts of the pass.","ref":"Passbook.PassStructure.html"},{"type":"type","title":"Passbook.PassStructure.field/0","doc":"","ref":"Passbook.PassStructure.html#t:field/0"},{"type":"type","title":"Passbook.PassStructure.t/0","doc":"","ref":"Passbook.PassStructure.html#t:t/0"},{"type":"type","title":"Passbook.PassStructure.transit_type/0","doc":"","ref":"Passbook.PassStructure.html#t:transit_type/0"},{"type":"extras","title":"Passbook for Elixir","doc":"# Passbook for Elixir [![Hex pm](https://img.shields.io/hexpm/v/passbook.svg?style=flat)](https://hex.pm/packages/passbook) [![hex.pm downloads](https://img.shields.io/hexpm/dt/passbook.svg?style=flat)](https://hex.pm/packages/passbook)\n\nElixir library to create Apple Wallet (.pkpass) files (Apple Wallet has previously been known as Passbook in iOS 6 to iOS 8).\n\nSee the [Wallet Topic Page](https://developer.apple.com/wallet/) and the\n[Wallet Developer Guide](https://developer.apple.com/library/ios/documentation/UserExperience/Conceptual/PassKit_PG/index.html#//apple_ref/doc/uid/TP40012195) for more information about Apple Wallet.","ref":"readme.html"},{"type":"extras","title":"Installation - Passbook for Elixir","doc":"This package can be installed by adding `passbook` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:passbook, \"~> 0.1.8\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started - Passbook for Elixir","doc":"1. Get a Pass Type Id\n\n- Visit the iOS Provisioning Portal -> Pass Type IDs -> New Pass Type ID\n- Select pass type id -> Configure (Follow steps and download generated pass.cer file)\n- Use Keychain tool to export a Certificates.p12 file (need Apple Root Certificate installed)\n\n2. Make sure you have open ssl installed, and generate the necessary certificate\n\n```shell\n    $ openssl pkcs12 -in \"Certificates.p12\" -clcerts -nokeys -out certificate.pem\n```\n\n3. Generate the key.pem\n\n```shell\n    $ openssl pkcs12 -in \"Certificates.p12\" -nocerts -out key.pem\n```\n\nYou will be asked for an export password (or export phrase), which you need to use when generating the `.pkpass` files.","ref":"readme.html#getting-started"},{"type":"extras","title":"Usage - Passbook for Elixir","doc":"```elixir\n\n      iex> Passbook.generate(%Passbook.Pass{\n        background_color: \"rgb(23, 187, 82)\",\n        foreground_color: \"rgb(100, 10, 110)\",\n        barcode: %Passbook.LowerLevel.Barcode{\n          format: :qr,\n          alt_text: \"1234\",\n          message: \"qr-code-content\"\n        },\n        description: \"This is a pass description\",\n        organization_name: \"My Organization\",\n        pass_type_identifier: \"123\",\n        serial_number: \"serial-number-123\",\n        team_identifier: \"team-identifier\",\n        generic: %Passbook.PassStructure{\n          transit_type: :train,\n          primary_fields: [\n            %Passbook.LowerLevel.Field{\n              key: \"my-key\",\n              value: \"my-value\"\n            }\n          ]\n        }}, [\"icon.png\": \"path/to/file.png\", \"icon@2x.png\": \"path/to/file.png\"], \"path/to/wwdr.pem\", \"path/to/certificate.pem\", \"path/to/key.pem\", \"password\", target_path: System.tmp_dir!(), pass_name: \"mypass\")\n      {:ok, \"path/to/generated/mypass.pkpass\"}\n```","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}